@@ -8,16 +8,10 @@ from ytscraper.helper.echo import echov
 
 
 @click.group()
-@click.option('--config-path',
-              '-c',
-              type=click.Path(),
-              help='YAML configuration file.')
-@click.option('--verbose',
-              '-v',
-              is_flag=True,
-              help='Show more verbose output.')
+@click.option("--config-path", "-c", type=click.Path(), help="YAML configuration file.")
+@click.option("--verbose", "-v", is_flag=True, help="Show more verbose output.")
 @click.pass_context
-def entry_point(context, config_path, verbose):
+def run(context, config_path, verbose):
     echov("Reading configuration file.", verbose)
     context.obj = {}
     update_config(context.obj, load_config(config_path))
@@ -25,9 +19,9 @@ def entry_point(context, config_path, verbose):
     if verbose:
         pprint(context.obj)
 
-    context.obj['verbose'] = verbose
+    context.obj["verbose"] = verbose
 
 
-entry_point.add_command(search.search)
-entry_point.add_command(fetch.fetch)
+run.add_command(search.search)
+run.add_command(fetch.fetch)
 
